@@ -4,7 +4,7 @@ test_that("Test audit_description", {
   repos = getOption("repos")
   on.exit(options(repos = repos))
   options(repos = c(CRAN = "https://cran.rstudio.com"))
-  aud = audit_description(".")
-  expect_equal(nrow(aud), 3)
+  aud = audit_description(test_path())
+  expect_gte(nrow(aud), 3)
   expect_equal(sum(aud$no_of_vulnerabilities), 0)
 })
